@@ -57,7 +57,7 @@ sub _restore_layers {
 my %texts = (
   short => 'Hello World',
   multiline => 'First line\nSecond line\n',
-  ( $] lt "5.008" ? () : ( unicode => 'Hi! \x{263a}\n') ),
+  ( "$]" < 5.008 ? () : ( unicode => 'Hi! \x{263a}\n') ),
 );
 
 #--------------------------------------------------------------------------#
